package
Version:
v0.0.0-...-ad8409f
Opens a new window with list of versions in this module.
Published: Apr 20, 2022
License: CC0-1.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Bios struct {
Vendor string `json:"vendor"`
Version string `json:"version"`
Date string `json:"date"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.