package
Version:
v0.0.0-...-ad8409f
Opens a new window with list of versions in this module.
Published: Apr 20, 2022
License: CC0-1.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Memory struct {
TotalPhysicalBytes int64 `json:"total_physical_bytes"`
TotalUsableBytes int64 `json:"total_usable_bytes"`
TotalBankUsed int `json:"total_bank_used"`
Modules []Modules `json:"modules"`
}
type Modules struct {
Label string `json:"label"`
Location string `json:"location"`
SerialNumber string `json:"serial_number"`
SizeBytes int64 `json:"size_bytes"`
Vendor string `json:"vendor"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.