package
Version:
v0.0.0-...-ad8409f
Opens a new window with list of versions in this module.
Published: Apr 20, 2022
License: CC0-1.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Product struct {
Family string `json:"family"`
Name string `json:"name"`
Vendor string `json:"vendor"`
SerialNumber string `json:"serial_number"`
UUID string `json:"uuid"`
Sku string `json:"sku"`
Version string `json:"version"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.